… | OiRA

Help

1. Preparation
2. Involve
3. Identification + Evaluation
   1. 1 Commercial manned guarding
   2. Ω Other risks
      1. Ω.1 The entrance floor is often wet
      2. Ω.2 …
   - Unanswered
   - Postponed
   - Risk identified
   - Risk with measures
4. Action Plan
5. Report
6. Status 0%

## Describe the risk…

If applicable, add all measures that have already been implemented. No, more measures are required Yes, the remaining risk is acceptable
Information
Upload image
Comments

Scroll to top
Back

## add-risk.html

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Loading Risk Assessments…